@@ -6,7 +6,7 @@
 #' @return None unless error in years being requested by users
 #' @noRd
 .validate_years <- function(years) {
-  if (class(years) == "character") {
+  if (inherits(years, what = "character")) {
     stop(call. = FALSE,
          "Years must be entered as a numeric value.")
   }
@@ -23,6 +23,7 @@
            "\nThe year cannot be greater than current year.\n")
     }
   }
+  return(invisible(NULL))
 }
 
 
@@ -48,9 +49,9 @@
     )
   }
   BEGIN <-
-    as.numeric(substr(isd_history[isd_history$STNID == station,]$BEGIN, 1, 4))
+    as.numeric(substr(isd_history[isd_history$STNID == station, ]$BEGIN, 1, 4))
   END <-
-    as.numeric(substr(isd_history[isd_history$STNID == station,]$END, 1, 4))
+    as.numeric(substr(isd_history[isd_history$STNID == station, ]$END, 1, 4))
   if (min(years) < BEGIN | max(years) > END) {
     message("\nThis station, ",
             station,
@@ -60,6 +61,7 @@
             END,
             ".\n")
   }
+  return(invisible(NULL))
 }
 
 
@@ -105,6 +107,7 @@
              "letter ISO country code\n")
       }
     }
+    return(country)
   }
 
 
@@ -263,7 +266,7 @@
 .agroclimatology_list <-
   function(file_list, isd_history, years) {
     station_list <- isd_history[isd_history$LAT >= -60 &
-                                  isd_history$LAT <= 60,]$STNID
+                                  isd_history$LAT <= 60, ]$STNID
     station_list <- gsub("-", "", station_list)
 
     station_list <-
@@ -294,7 +297,7 @@
            isd_history,
            years) {
     station_list <-
-      isd_history[isd_history$CTRY == country,]$STNID
+      isd_history[isd_history$CTRY == country, ]$STNID
     station_list <- gsub("-", "", station_list)
     station_list <-
       CJ(years, sorted = FALSE)[, paste0(tempdir(),
