@@ -1,6 +1,7 @@
-test_that(
-  ".download_files properly works, subsetting for country and
-  agroclimatology works", {
+
+test_that(".download_files properly works, subsetting for country and
+  agroclimatology works",
+  {
     skip_on_cran()
     do.call(file.remove, list(list.files(
       tempdir(),
@@ -16,21 +17,17 @@ test_that(
     setkey(isd_history, "STNID")
     stations <- isd_history
 
-    load(system.file("extdata", "isd_history.rda",
-                     package = "GSODR"))
-
     GSOD_list <- .download_files(station,
                                  years)
 
     agro_list <- .agroclimatology_list(GSOD_list,
                                        stations,
                                        years)
-    expect_length(agro_list, 7480)
+    expect_length(agro_list, 7545)
 
     RP_list <- .subset_country_list(country,
                                     GSOD_list,
                                     stations,
                                     years)
     expect_length(RP_list, 54)
-  }
-)
+  })
